clear
clc
close all

% parametere inngang
u0        = 4*pi*1e-7;      % Permeabilitet Konstant (H/m), vakuum
rho       = 1.8335e-8;      % Resistivitet (Ohm*m)
f         = [0:20000] ;     % frekvens (Hz)
tverrsnitt = 95e-6;         % Arealet av lederen (m^2)

% kalkulerer mellomliggende parameter
Radius_m    = sqrt(tverrsnitt/pi);              % Radius i (m)
D_leder_m   = Radius_m*2;                       % leder-Diameter (m)
sigma       = 1/rho;                            % Konduktivitet, (S/m)
omega       = 2*pi*f;                           % vinkelfrekvens (Rad/s)
SD = sqrt((2)./(omega*sigma*u0));               % Beregning av skinndybde
R_DC = rho/tverrsnitt;                          %DC motstand i lederen


k  = sqrt(-1j*omega*sigma*u0); % Normalisert argument for Bessel funksjon 
kr = k.*Radius_m;              % Konstant kr
J0 = besselj ( 0 , kr )  ;        % første bessel-funksjon av nullte-orden
J1 = besselj ( 1 , kr );          % Andre bessel-funksjon første orden
z_math = 1*k./(sigma*2*pi.*Radius_m).*J0./J1;    % impedansen i leder per meter
LBessel = imag(z_math)./omega;      % Induktans i leder per meter
RBessel = real(z_math);             % Resistans i leder per meter


k = sqrt(1j*omega*u0*sigma);
kr = k.*Radius_m;
syms n
I0 = double(symsum (1./(factorial(n)).^2 * (kr./2).^(2.*n)   , n, 0, 10));                   % summen Modifisert Bessel-funsjon i nulte orden
I1 = double(symsum (1./(factorial(n).*factorial(1+n)) .* (kr./2).^(2.*n+1)   , n, 0, 10));   % summen Modifisert Bessel-funsjon i føste orden
zI = 1*k./(sigma*2*pi.*Radius_m).*I0./I1; % impedansen i leder per meter
LBessel1 = imag(zI)./omega; % induktans i leder per meter
RBessel1 = real(zI);    % Resistans i leder per meter

figure
xlabel('Frekvens (Hz)')
title('Motstand og induktans i leder per meter Bessel-funksjon') %tittel navn

grid on
yyaxis left                
semilogx(f,RBessel, '--', 'DisplayName','Motstand matlab-formel')              % Plotter motstanden i besselfunksjonen
hold on
semilogx(f,RBessel1,'g-', 'DisplayName','Motstand manuelt beregnet')           % plotter motstanden i manuelt beregnet bessel-funksjonen
ylabel('Motstand (ohm)')             % Navngir Y aksen (ohm)

%graf høgre akse induktans 
yyaxis right                         % Definerer Høyre Y-Akse
semilogx(f,LBessel, '--', 'DisplayName','Induktans matlab-formel')                % Plotter spolen i besselfunksjonen
semilogx(f,LBessel1, '-', 'DisplayName','Induktans manuelt beregnet')             % plotter spolen i manuelt beregnet bessel-funksjonen
ylabel('Induktans (H)')              % Navngir Y aksene
legend
hold off
