clear
clc
close all

%% Program for plotting av forskjellige grener i eksanderende RL-krets.
% Fyll inn ønsket parametere for inngang, og programmet plotter Bessel
% sammen med 1, 2, 3, 4 og 5 grener i ekspanderende RL krets. Kan se på
% forskjellige frekvenser for feilmargin i prosent ved å endre på
% variabelen (b) i linje 125.

%% parametere inngang
rho = 1.8335e-8;            % Resistivitet (Ohm*m), kopper 
l_m  = 18;                  % Leder-lengde
f = [1:1000];                % Frekvens (Hz)
A = 95e-6;                  % Areal i (m^2)
u0 = 4*pi*1e-7;             % Permabilitet konstant (H/m), vakuum
X = sqrt(10);               % Konstant X 
T0 = 20;                    % temperatur 0-faktor
T1 = 20;                    % Temperatur i kabelen
Alfa = 3.9*10^-3;           % Temperaturkoeffisent (kobber 3,9*10^-3), (Aluminium 4*10^-3)    [K^-1] 

%% kalkulerer mellomliggende parameter
rho_T1 = rho + Alfa * rho * (T1 - T0);                                      % Beregner Resistivitet ved oppgitt temperatur
r_m    = sqrt(A/pi);                                                        % Beregner Radius
sigma       = 1./rho_T1;                                                    % Beregner Konduktiviteten
R_DC        = l_m./(sigma.*A);                                              % DC-motstanden
Linternal = ((u0*l_m)/(8*pi));                                              % Interne induktans
Lexternal = ((u0 * l_m) / (2*pi)) * (log((2*l_m)/(r_m))-1);                 % Eksterne induktans
omega       = 2.*pi.*f;                                                     % Vinkelfrekvens
skinndybde  = 1./(sqrt(omega.*sigma.*u0./2));                               % Skinndybde (m)

%% parametre utgang for Bessel
z_math =  Z_wire (omega, r_m, sigma, u0);  % intern-impedanse for lederen Bessel;
L_H    =  (imag(z_math)./omega).*l_m;      % total-induktans i lederen Bessel
R_ohm  =  real(z_math).*l_m;               % total-motstand i lederen Bessel

%% 1-Ladder

enR1 = R_DC;            % R1
enL1 = Linternal;       % L1
enXL1 = omega .* enL1;  % XL1

enZLadder = enR1 + 1j.*enXL1;   % Impedanse
enRLadder = real(enZLadder);    % Motstand
enXLLadder = imag(enZLadder);   % Reaktans
enLladder = enXLLadder./omega;  % Induktans

%% 2-LADDER

toR1 = 1.32*R_DC;         % R1
toR2 = toR1*X;            % R2
toL1 = 1.68*Linternal;    % L1
toL2 = toL1/X;            % L2
toXL1 = omega * toL1;     % XL1
toXL2 = omega * toL2;     % XL2

toZLadder = 1./((1./(toR1+1j*toXL1)) + (1./(toR2+1j*toXL2)));   % Impedanse
toRLadder = real(toZLadder);      % Motstand
toXLLadder = imag(toZLadder);     % Reaktans
toLladder = toXLLadder./omega;    % Induktans


%% 3-LADDER

treR1 = 1.42*R_DC;          % R1
treR2 = treR1*X;            % R2
treR3 = treR1*X^2;          % R3
treL1 = 1.94*Linternal;     % L1
treL2 = treL1/X;            % L2
treL3 = treL1/X^2;          % L3
treXL1 = omega * treL1;     % XL1               
treXL2 = omega * treL2;     % XL2
treXL3 = omega * treL3;     % XL3

treZLadder = 1./((1./(treR1+1j*treXL1)) + (1./(treR2+1j*treXL2)) + (1./(treR3+1j*treXL3)));    % Impedanse
treRLadder = real(treZLadder);       % Motstand
treXLLadder = imag(treZLadder);      % Reaktans
treLladder = treXLLadder./omega;     % Induktans

%% 4-LADDER

fireR1 = 1.45*R_DC;          % R1                                                                       
fireR2 = fireR1*X;           % R2
fireR3 = fireR1*X^2;         % R3
fireR4 = fireR1*X^3;         % R4
fireL1 = 2.03*Linternal;     % L1
fireL2 = fireL1/X;           % L2
fireL3 = fireL1/X^2;         % L3
fireL4 = fireL1/X^3;         % L4
fireXL1 = omega * fireL1;    % XL1
fireXL2 = omega * fireL2;    % XL2
fireXL3 = omega * fireL3;    % XL3
fireXL4 = omega * fireL4;    % XL4

fireZLadder = 1./((1./(fireR1+1j*fireXL1)) + (1./(fireR2+1j*fireXL2)) + (1./(fireR3+1j*fireXL3)) + (1./(fireR4+1j*fireXL4)));  % Impedanse
fireRLadder = real(fireZLadder);       % Motstand
fireXLLadder = imag(fireZLadder);      % Reaktans
fireLladder = fireXLLadder./omega;     % Induktans

%% 5-LADDER

femR1 = 1.457*R_DC;         % R1
femR2 = femR1*X;            % R2
femR3 = femR1*X^2;          % R3
femR4 = femR1*X^3;          % R4
femR5 = femR1*X^4;          % R5
femL1 = 2.06*Linternal;     % L1
femL2 = femL1/X;            % L2
femL3 = femL1/X^2;          % L3
femL4 = femL1/X^3;          % L4
femL5 = femL1/X^4;          % L5
femXL1 = omega * femL1;     % XL1
femXL2 = omega * femL2;     % XL2
femXL3 = omega * femL3;     % XL3
femXL4 = omega * femL4;     % XL4
femXL5 = omega * femL5;     % XL5

femZLadder = 1./((1./(femR1+1j*femXL1)) + (1./(femR2+1j*femXL2)) + (1./(femR3+1j*femXL3)) + (1./(femR4+1j*femXL4)) + (1./(femR5+1j*femXL5))); % Impedanse
femRLadder = real(femZLadder);      % Motstand
femXLLadder = imag(femZLadder);     % Reaktans
femLladder = femXLLadder./omega;    % Induktans

%% Feilmargin i prosent for Ladderene

b = 600;  % frekvensen en ønsker å se feilmargin på

Forskjell_Rtoladder = 100 * ((toRLadder(b) - R_ohm(b))/R_ohm(b));        %Feilmargin motstand 2-grener
Forskjell_Ltoladder = 100 * ((toLladder(b) - L_H(b))/L_H(b));            %Feilmargin spole 2-grener
Forskjell_Rtreladder = 100 * ((treRLadder(b) - R_ohm(b))/R_ohm(b))      %Feilmargin motstand 3-grener
Forskjell_Ltreladder = 100 * ((treLladder(b) - L_H(b))/L_H(b))          %Feilmargin spole 3-grener
Forskjell_Rfireladder = 100 * ((fireRLadder(b) - R_ohm(b))/R_ohm(b));    %Feilmargin motstand 4-grener
Forskjell_Lfireladder = 100 * ((fireLladder(b) - L_H(b))/L_H(b));        %Feilmargin spole 4-grener
Forskjell_Rfemladder = 100 * ((femRLadder(b) - R_ohm(b))/R_ohm(b));      %Feilmargin motstand 5-grener
Forskjell_Lfemladder = 100 * ((femLladder(b) - L_H(b))/L_H(b));          %Feilmargin spole 4-grener


%% plot over motstand og induktans avhengig av frekvens

figure
xlabel('Frekvens (Hz)')             % navngir x-aksen
title('induktans')

grid on
 yyaxis left                
semilogx(f,R_ohm, 'k-','DisplayName','Bessel: motstand')                                   % Plotter motstanden i besselfunksjonen
hold on
%semilogx(f,femRLadder,'g--', 'DisplayName', 'Ekspanderende ladder 5-Grener: motstand')      % Plotter motstanden for 5-grener
%semilogx(f,fireRLadder,'r--', 'DisplayName', 'Ekspanderende ladder 4-Grener: motstand')     % Plotter motstanden for 4-grener
semilogx(f,treRLadder,'b--', 'DisplayName', 'Ekspanderende ladder 3-Grener: motstand')      % Plotter motstanden for 3-grener
%semilogx(f,toRLadder,'m--', 'DisplayName', 'Ekspanderende ladder 2-Grener: motstand')       % Plotter motstanden for 2-grener
%semilogx(f,enRLadder,'--', 'DisplayName', 'Ekspanderende ladder 1-Grener: motstand')        % Plotter motstanden for 1-grener
ylabel('Motstand (ohm)')        % Navngir Y aksen (ohm)

%Graf høgre akse induktans 
yyaxis right                    % Definerer Høyre Y-Akse
semilogx(f,L_H, 'k-','DisplayName', 'Bessel: induktans ')                                    % Plotter spolen i besselfunksjonen
hold on
%semilogx(f,femLladder,'g--', 'DisplayName', 'Ekspanderende ladder 5-Grener: induktans')      % Plotter spolen for 5-grener
%semilogx(f,fireLladder,'r--', 'DisplayName', 'Ekspanderende ladder 4-Grener: induktans')     % Plotter spolen for 4-grener
semilogx(f,treLladder,'b--', 'DisplayName', 'Ekspanderende ladder 3-Grener: induktans')      % Plotter spolen for 3-grener
%semilogx(f,toLladder, 'm--', 'DisplayName', 'Ekspanderende ladder 2-Grener: induktans')      % Plotter spolen for 2-grener
%semilogx(f,enLladder, '--', 'DisplayName', 'Ekspanderende ladder 1-Grener: induktans')       % Plotter spolen for 1-grener
ylabel('Induktans (H)')        % Navngir Y aksen

legend
hold off

%% Impedansemodell med Besselfunksjon
function [z_math] = Z_wire (omega, R, sigma, u0)

  A  = sqrt(-1j*omega*sigma*u0);                                           % Normalisert argument for Bessel funksjon 
  J0 = besselj ( 0 , A.* R );                                              % første bessel-function of null-orden
  J1 = besselj ( 1 , A.* R );                                              % første bessel-function of første-orden
  z_math = A./(sigma*2*pi.*R).*J0./J1;                                     % impedanse
  
end






