clear
clc
close all

%% Beregning av parametre for testing i simulink.
% Programmet regner ut parametre for bruk av simulink filen
% "Simulering_Kortslutning_Ekspanderende_Ladder"
% En må ta skrive inn ønskelige parametre på inngang, og dermed beregner
% programmet ut utparametere for filen.

%% parametere inngang
rho = 1.8335e-8;            % Resistivitet (Ohm*m), kopper 
l_m  = 36;                  % leder-lengde
f = 120;                    % frekvens (Hz)
A = 95e-6;                  % Areal i (m^2)
u0 = 4*pi*1e-7;             % Permabilitet konstant (H/m), vakuum
X = sqrt(10);               % Konstant X 
T0 = 20;                    % temperatur 0-faktor
T1 = 20;                    % Temperatur i kabelen
Alfa = 3.9*10^-3;           % Temperaturkoeffisent (kobber 3,9*10^-3), (Aluminium 4*10^-3)    [K^-1] 
C_bank = 13.5e-3*0.041;           % Kondensatorbank

%% kalkulerer mellomliggende parameter
rho_T1 = rho + Alfa * rho * (T1 - T0);                        % Beregner Resistivitet ved oppgitt temperatur
r_m    = sqrt(A/pi);                                          % Beregner Radius
D_leder_m   = r_m*2;                                          % Beregner Diameteren
sigma       = 1./rho_T1;                                      % Beregner Konduktiviteten
R_DC        = l_m./(sigma.*A);                                % DC-motstanden
Linternal = (((u0*l_m)/(8*pi))) ;                             % Interne induktans
Lexternal = ((u0 * l_m) / (2*pi)) * (log((2*l_m)/(r_m))-1);   % Eksterne induktans
omega       = 2.*pi.*f;                                       % Vinkelfrekvens
skinndybde  = 1./(sqrt(omega.*sigma.*u0./2));                 % Skinndybde (m)
%% parametre utgang for Bessel
z_math =  Z_wire (omega, r_m, sigma, u0);  % intern-impedanse for lederen Bessel;
L_H    =  (imag(z_math)./omega).*l_m;      % total-induktans i lederen Bessel
R_ohm  =  real(z_math).*l_m;               % total-motstand i lederen Bessel
%% 3-LADDER

R1 = 1.42*R_DC;       % R1
R2 = R1*X;            % R2
R3 = R1*X^2;          % R3
L1 = 1.94*Linternal;  % L1
L2 = L1/X;            % L2
L3 = L1/X^2;          % L3
XL1 = omega * L1;     % XL1               
XL2 = omega * L2;     % XL2
XL3 = omega * L3;     % XL3

ZLadder = 1./((1./(R1+1j*XL1)) + (1./(R2+1j*XL2)) + (1./(R3+1j*XL3)));    % Impedanse
RLadder = real(ZLadder);       % Motstand
XLLadder = imag(ZLadder);      % Reaktans
Lladder = XLLadder./omega;     % Induktans

% t = simout.time;
% volt = simout.signals.values(:,1);
% 
% plot(t,volt)

ZtotalLadder = 1j*XLLadder + 1j*omega*Lexternal + (0.064e-6 *1j * omega) -(1j*omega * C_bank *2) + RLadder + ((2*9.515e-3 * 2*9.515e-3) / (4*9.515e-3)) + 1.2e-3

(20.3101/0.0178)
(0.0178/20.3101) * 100
XLLadder + Lexternal *omega
RLadder
0.0471/0.0071
%% Impedansemodell med Besselfunksjon
function [z_math] = Z_wire (omega, R, sigma, u0)

  A  = sqrt(-1j*omega*sigma*u0);          % Normalisert argument for Bessel funksjon 
  J0 = besselj ( 0 , A.* R );             % første bessel-function of null-orden
  J1 = besselj ( 1 , A.* R );             % første bessel-function of første-orden
  z_math = A./(sigma*2*pi.*R).*J0./J1;    % impedanse
  
end






